<?php

namespace Bookit\Classes;

use Bookit\Classes\Database\Categories;
use Bookit\Classes\Database\Customers;
use Bookit\Classes\Database\Services;
use Bookit\Classes\Database\Staff;
use Bookit\Classes\Admin\SettingsController;
use Bookit\Helpers\TimeSlotHelper;

class BookitController {

    /**
     * Bookit Calendar Frontend
     */
    public static function init() {
        add_shortcode( 'bookit', [self::class, 'render_shortcode'] );
    }

    /**
     * Enqueue Frontend Styles & Scripts
     */
	/**
	 * @param $settings
	 */
    public static function enqueue_styles_scripts( $settings, $is_admin = false ) {
        wp_enqueue_script( 'bookit-app', BOOKIT_URL . 'assets/dist/frontend/js/app.js', [], BOOKIT_VERSION);

        if ( bookit_pro_active() ) {
	        wp_enqueue_script( 'bookit-stripe-js', 'https://js.stripe.com/v3/', array(), false, false );
        }

        $styles = $is_admin ? BOOKIT_URL . 'assets/dist/dashboard/css/app.css':BOOKIT_URL . 'assets/dist/frontend/css/app.css';

        if ( $settings['custom_colors_enabled'] == 'true' ) {
	        $upload         = wp_upload_dir();
	        $styles_path    = $upload['basedir'] . '/bookit/app.css';
	        if ( file_exists( $styles_path ) ) {
		        $styles = $upload['baseurl'] . '/bookit/app.css';
	        }
        }

	    wp_enqueue_style( 'bookit-app', $styles, [], intval( get_option( 'bookit_styles_version', BOOKIT_VERSION ) ));

	    $ajax_data = [
		    'ajax_url'      => admin_url( 'admin-ajax.php' ),
		    'translations'  => Translations::get_frontend_translations(),
		    'nonces'        => Nonces::get_frontend_nonces()
	    ];

	    wp_localize_script( 'bookit-app', 'bookit_window', $ajax_data );
    }

    /**
     * Render Frontend Bookit Calendar
     *
	 * @param bool $display
	 * @param bool $is_admin
	 * @param null $category_id
	 * @param null $service_id
	 * @param null $staff_id
	 *
	 * @return bool|string
	 */
    public static function render_calendar( $display = false, $is_admin = false, $category_id = null, $service_id = null, $staff_id = null ) {
	    $categories                 = ( ! empty( $category_id ) ) ? Categories::get_one($category_id) : Categories::get_all();
	    $services                   = ( ! empty( $service_id ) ) ? [Services::get('id', $service_id)] : Services::get_assigned_to_staff();
	    $staff                      = ( ! empty( $staff_id ) ) ? Staff::get_one($staff_id) : Staff::get_all();
	    $settings                   = SettingsController::get_settings();
	    $settings['date_format']    = bookit_php_to_moment(get_option('date_format'));
	    $settings['time_format']    = bookit_php_to_moment(get_option('time_format'));
	    $settings['pro_active']     = bookit_pro_active();
	    $user                       = ( is_user_logged_in() ) ? wp_get_current_user() : null;
	    $language                   = substr( get_bloginfo( 'language' ), 0, 2 );
	    $theme                      = $is_admin ? 'admin' : $settings['theme'];

	    $service_start  = 0;
	    $service_end    = TimeSlotHelper::DAY_IN_SECONDS;
	    $time_slot_list = TimeSlotHelper::getTimeList($service_start, $service_end);

	    if ( ! empty( $services ) ) {
		    foreach ( $services as &$service ) {
		    	if ( is_array( $service ) ) {
				    $service['icon_url'] = ( ! empty( $service['icon_id'] ) ) ? wp_get_attachment_url($service['icon_id']) : null;
			    }
		    }
	    }

	    if ( ! empty( $user->ID ) ) {
		    $user = (object) array_merge( (array) $user->data, [ 'customer' => Customers::get('wp_user_id', $user->ID) ] );
	    }

	    self::enqueue_styles_scripts( $settings, $is_admin );

        return Template::load_template( 'bookit-calendar', [
        	'categories'    => $categories,
        	'services'      => $services,
        	'staff'         => $staff,
        	'settings'      => $settings,
        	'user'          => $user,
        	'language'      => $language,
        	'theme'         => $theme,
	        'slot_list'     => $time_slot_list,
        ], $display );
    }

	/**
	 * Shortcode
	 * @param $atts
	 *
	 * @return bool|string
	 */
	public static function render_shortcode( $atts ) {
		$atts = shortcode_atts( array(
			'category'  => null,
			'service'   => null,
			'staff'     => null,
		), $atts, 'bookit' );

		return self::render_calendar( false, false, $atts['category'], $atts['service'], $atts['staff'] );
	}

	/**
	 * Render Dashboard Bookit Calendar
	 * @return bool|string
	 */
	public static function render_calendar_dashboard() {
		self::render_calendar( true, true );
	}
}